from setuptools import setup

setup(
    name='my_road',
    version='2.0.0',
    description='long Road or not????',
    py_modules=['my_road'],
    author='k0ng999',
    author_email='baydar_14@mail.ru',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    license='MIT',
)
